==> php54-owncloud-8.0.4.tgz: share/owncloud/core/l10n/az.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "Məktubu göstərilən istifadəçilərə göndərmək mümkün olmadı: %s",
    "Turned on maintenance mode" : "Xidməti rejimə keçilmişdir",
    "Turned off maintenance mode" : "Xidməti rejim söndürüldü",
    "Updated database" : "Yenilənmiş verilənlər bazası",
    "Checked database schema update" : "Baza sxeminin yenilənməsi yoxlanıldı",
    "Unknown filetype" : "Fayl tipi bəlli deyil.",
    "Invalid image" : "Yalnış şəkil",
    "No temporary profile picture available, try again" : "Profaylın müvəqqəti şəklinə çatmaq mümkün olmadı, yenidən təkrarlayın.",
    "Sunday" : "Bazar",
    "Monday" : "Bazar ertəsi",
    "Settings" : "Quraşdırmalar",
    "Saving..." : "Saxlama...",
    "No" : "Xeyir",
    "Yes" : "Bəli",
    "Ok" : "Oldu",
    "_{count} file conflict_::_{count} file conflicts_" : ["",""],
    "Cancel" : "Dayandır",
    "Very weak password" : "Çox asan şifrə",
    "Weak password" : "Asan şifrə",
    "So-so password" : "Elə-belə şifrə",
    "Good password" : "Yaxşı şifrə",
    "Strong password" : "Çətin şifrə",
    "Share" : "Yayımla",
    "Error" : "Səhv",
    "Share link" : "Linki yayımla",
    "Password" : "Şifrə",
    "Send" : "Göndər",
    "group" : "qrup",
    "can share" : "yayımlaya bilərsiniz",
    "delete" : "sil",
    "Email sent" : "Məktub göndərildi",
    "Warning" : "Xəbərdarlıq",
    "Delete" : "Sil",
    "Add" : "Əlavə etmək",
    "_download %n file_::_download %n files_" : ["",""],
    "_{count} search result in other places_::_{count} search results in other places_" : ["",""],
    "Personal" : "Şəxsi",
    "Users" : "İstifadəçilər",
    "Admin" : "İnzibatçı",
    "Help" : "Kömək",
    "Security Warning" : "Təhlükəsizlik xəbərdarlığı",
    "Username" : "İstifadəçi adı",
    "Search" : "Axtarış",
    "You are accessing the server from an untrusted domain." : "Siz serverə inamsız domain-dən girməyə çalışırsız.",
    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Xahiş olunur inzibatçı ilə əlaqə saxlayasınız. Eger siz bu xidmətin inzibatçısısınizsa, \"trusted_domain\" configini config/config.php faylinda düzgün qeyd edin.  Config nüsxəsi config/config.sample.php faylında qeyd edilmişdir."
},
"nplurals=2; plural=(n != 1);");

==> php54-owncloud-8.1.0.tgz: share/owncloud/core/l10n/az.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "Məktubu göstərilən istifadəçilərə göndərmək mümkün olmadı: %s",
    "Turned on maintenance mode" : "Xidməti rejimə keçilmişdir",
    "Turned off maintenance mode" : "Xidməti rejim söndürüldü",
    "Updated database" : "Yenilənmiş verilənlər bazası",
    "Checked database schema update" : "Baza sxeminin yenilənməsi yoxlanıldı",
    "Unknown filetype" : "Fayl tipi bəlli deyil.",
    "Invalid image" : "Yalnış şəkil",
    "No temporary profile picture available, try again" : "Profaylın müvəqqəti şəklinə çatmaq mümkün olmadı, yenidən təkrarlayın.",
    "Sunday" : "Bazar",
    "Monday" : "Bazar ertəsi",
    "Tuesday" : "Çərşənbə axşamı",
    "Wednesday" : "Çərşənbə",
    "Thursday" : "Cümə axşamı",
    "Friday" : "Cümə",
    "Saturday" : "Şənbə",
    "January" : "Yanvar",
    "February" : "Fevral",
    "March" : "Mart",
    "April" : "Aprel",
    "May" : "May",
    "June" : "İyun",
    "July" : "İyul",
    "August" : "Avqust",
    "September" : "Sentyabr",
    "October" : "Oktyabr",
    "November" : "Noyabr.",
    "December" : "Dekabr",
    "Settings" : "Quraşdırmalar",
    "Saving..." : "Saxlama...",
    "No" : "Xeyir",
    "Yes" : "Bəli",
    "Choose" : "Seç",
    "Ok" : "Oldu",
    "Cancel" : "Dayandır",
    "Very weak password" : "Çox asan şifrə",
    "Weak password" : "Asan şifrə",
    "So-so password" : "Elə-belə şifrə",
    "Good password" : "Yaxşı şifrə",
    "Strong password" : "Çətin şifrə",
    "Share" : "Yayımla",
    "Error" : "Səhv",
    "Share link" : "Linki yayımla",
    "Password" : "Şifrə",
    "Send" : "Göndər",
    "Expiration" : "Vaxtın bitməsi",
    "group" : "qrup",
    "Unshare" : "Paylaşımı durdur",
    "can share" : "yayımlaya bilərsiniz",
    "can edit" : "dəyişmək olar",
    "delete" : "sil",
    "Email sent" : "Məktub göndərildi",
    "Warning" : "Xəbərdarlıq",
    "Delete" : "Sil",
    "Add" : "Əlavə etmək",
    "New password" : "Yeni şifrə",
    "Personal" : "Şəxsi",
    "Users" : "İstifadəçilər",
    "Admin" : "İnzibatçı",
    "Help" : "Kömək",
    "Cheers!" : "Şərəfə!",
    "Username" : "İstifadəçi adı",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Xüsusilə fayl sinxronizasiyası üçün desktop client-dən istifadə edilərsə, SQLite məsləhət görülmür.",
    "Search" : "Axtarış",
    "Log in" : "Giriş",
    "You are accessing the server from an untrusted domain." : "Siz serverə inamsız domain-dən girməyə çalışırsız.",
    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Xahiş olunur inzibatçı ilə əlaqə saxlayasınız. Eger siz bu xidmətin inzibatçısısınizsa, \"trusted_domain\" configini config/config.php faylinda düzgün qeyd edin.  Config nüsxəsi config/config.sample.php faylında qeyd edilmişdir."
},
"nplurals=2; plural=(n != 1);");
